@@ -48,7 +48,6 @@ class HistoryExportResult:
 #   per_page - int64 - Number of records to show per page.  (Max: 10,000, 1,000 or less is recommended).
 #   action - string - Deprecated: If set to `count` returns a count of matching records rather than the records themselves.
 #   cursor - string - Send cursor to resume an existing list from the point at which you left off.  Get a cursor from an existing list via the X-Files-Cursor-Next header.
-#   sort_by - object - If set, sort records by the specified field in either 'asc' or 'desc' direction (e.g. sort_by[last_login_at]=desc). Valid fields are `created_at`.
 #   history_export_id (required) - int64 - ID of the associated history export.
 def list(params = {}, options = {}):
     if "user_id" in params and not isinstance(params["user_id"], int):
@@ -61,8 +60,6 @@ def list(params = {}, options = {}):
         raise InvalidParameterError("Bad parameter: action must be an str")
     if "cursor" in params and not isinstance(params["cursor"], str):
         raise InvalidParameterError("Bad parameter: cursor must be an str")
-    if "sort_by" in params and not isinstance(params["sort_by"], dict):
-        raise InvalidParameterError("Bad parameter: sort_by must be an dict")
     if "history_export_id" in params and not isinstance(params["history_export_id"], int):
         raise InvalidParameterError("Bad parameter: history_export_id must be an int")
     if "history_export_id" not in params:
